@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 #
-#   Copyright (C) 2008-2010, 2013-2021, 2023-2024 Rocky Bernstein
+#   Copyright (C) 2008-2010, 2013-2021, 2023-2025 Rocky Bernstein
 #   <rocky@gnu.org>
 #
 #   This program is free software: you can redistribute it and/or modify
@@ -15,6 +15,7 @@
 #
 #   You should have received a copy of the GNU General Public License
 #   along with this program.  If not, see <http://www.gnu.org/licenses/>.
+
 import importlib
 import inspect
 import linecache
@@ -22,40 +23,29 @@ import os.path as osp
 import re
 import shlex
 import sys
-import tempfile
 import traceback
 
 # Note: the module name pre 3.2 is repr
 from reprlib import Repr
+from typing import Optional, Tuple
 
 import pyficache
 from pygments.console import colorize
-from tracer import EVENT2SHORT
+from tracer import EVENT2SHORT, remove_hook
 
 import trepan.exception as Mexcept
 import trepan.lib.display as Mdisplay
 import trepan.lib.file as Mfile
-import trepan.lib.stack as Mstack
 import trepan.lib.thred as Mthread
 import trepan.misc as Mmisc
-import trepan.processor.complete as Mcomplete
+from trepan.interfaces.script import ScriptInterface
 from trepan.lib.bytecode import is_class_def, is_def_stmt
-from trepan.processor import cmdfns
-from trepan.processor.cmdfns import deparse_fn
+from trepan.processor.complete_rl import completer
+from trepan.processor.print import print_location
 from trepan.vprocessor import Processor
 
-try:
-    from trepan.lib.deparse import deparse_and_cache
 
-    have_deparse_and_cache = True
-except ImportError:
-    have_deparse_and_cache = False
-    pass
-
-warned_file_mismatches = set()
-
-
-def get_srcdir():
+def get_srcdir() -> str:
     filename = osp.normcase(osp.dirname(osp.abspath(__file__)))
     return osp.realpath(filename)
 
@@ -88,7 +78,7 @@ def arg_split(s, posix=False):
     return args_list
 
 
-def get_stack(f, t, botframe, proc_obj=None):
+def get_stack(f, t, botframe, proc_obj=None) -> Tuple[list, int]:
     """Return a stack of frames which the debugger will use for in
     showing backtraces and in frame switching. As such various frame
     that are really around may be excluded unless we are debugging the
@@ -99,7 +89,7 @@ def get_stack(f, t, botframe, proc_obj=None):
         return false_fn
 
     def fn_is_ignored(f):
-        return proc_obj.core.ignore_filter.is_included(f)
+        return proc_obj.core.ignore_filter.is_excluded(f)
 
     exclude_frame = false_fn
     if proc_obj:
@@ -128,16 +118,15 @@ def get_stack(f, t, botframe, proc_obj=None):
     return stack, i
 
 
-def run_hooks(obj, hooks, *args):
-    """Run each function in `hooks' with args"""
-    for hook in hooks:
-        if hook(obj, *args):
-            return True
-        pass
-    return False
+def run_hooks(obj, hooks, *args) -> bool:
+    """Run each function in `hooks' with args
+    Returns True if a hook failed and so the caller should
+    leave its command loop.
+    """
+    return any((hook(obj, *args) for hook in hooks))
 
 
-def resolve_name(obj, command_name):
+def resolve_name(obj, command_name) -> Optional[str]:
     if command_name.lower() not in obj.commands:
         if command_name in obj.aliases:
             command_name = obj.aliases[command_name]
@@ -152,246 +141,6 @@ def resolve_name(obj, command_name):
     return
 
 
-def print_source_line(msg, lineno, line, event_str=None):
-    """Print out a source line of text , e.g. the second
-    line in:
-        (/tmp.py:2):  <module>
-        L -- 2 import sys,os
-        (trepan3k)
-
-    We define this method
-    specifically so it can be customized for such applications
-    like ipython."""
-
-    # We don't use the filename normally. ipython and other applications
-    # however might.
-    return msg("%s %d %s" % (event_str, lineno, line))
-
-
-def print_source_location_info(
-    print_fn, filename, lineno, fn_name=None, f_lasti=None, remapped_file=None
-):
-    """Print out a source location , e.g. the first line in
-    line in:
-        (/tmp.py:2 @21):  <module>
-        L -- 2 import sys,os
-        (trepan3k)
-    """
-    if remapped_file:
-        mess = f"({remapped_file}:{lineno} remapped {filename}"
-    else:
-        mess = f"({filename}:{lineno}"
-    if f_lasti and f_lasti != -1:
-        mess += " @%d" % f_lasti
-        pass
-    mess += "):"
-    if fn_name and fn_name != "?":
-        mess += f" {fn_name}"
-        pass
-    print_fn(mess)
-    return
-
-
-def print_location(proc_obj):
-    """Show where we are. GUI's and front-end interfaces often
-    use this to update displays. So it is helpful to make sure
-    we give at least some place that's located in a file.
-    """
-    i_stack = proc_obj.curindex
-    if i_stack is None or proc_obj.stack is None:
-        return False
-    core_obj = proc_obj.core
-    dbgr_obj = proc_obj.debugger
-    intf_obj = dbgr_obj.intf[-1]
-
-    # Evaluation routines like "exec" don't show useful location
-    # info. In these cases, we will use the position before that in
-    # the stack.  Hence the looping below which in practices loops
-    # once and sometimes twice.
-    remapped_file = None
-    source_text = None
-    while i_stack >= 0:
-        frame, lineno = proc_obj.stack[i_stack]
-
-        # Before starting a program a location for a module with
-        # line number 0 may be reported. Treat that as though
-        # we were on the first line.
-        if frame.f_code.co_name == "<module>" and lineno == 0:
-            lineno = 1
-
-        i_stack -= 1
-
-        #         # Next check to see that local variable breadcrumb exists and
-        #         # has the magic dynamic value.
-        #         # If so, it's us and we don't normally show this.a
-        #         if 'breadcrumb' in frame.f_locals:
-        #             if self.run == frame.f_locals['breadcrumb']:
-        #                 break
-
-        filename = Mstack.frame2file(core_obj, frame, canonic=False)
-        if "<string>" == filename and dbgr_obj.eval_string:
-            remapped_file = filename
-            filename = pyficache.unmap_file(filename)
-            if "<string>" == filename:
-                remapped = cmdfns.source_tempfile_remap(
-                    "eval_string",
-                    dbgr_obj.eval_string,
-                    tempdir=proc_obj.settings("tempdir"),
-                )
-                pyficache.remap_file(filename, remapped)
-                filename, lineno = pyficache.unmap_file_line(filename, lineno)
-                pass
-            pass
-        elif "<string>" == filename:
-            source_text = deparse_fn(frame.f_code)
-            filename = f"<string: '{source_text}'>"
-            pass
-        else:
-            m = re.search("^<frozen (.*)>", filename)
-            if m and m.group(1) in pyficache.file2file_remap:
-                remapped_file = pyficache.file2file_remap[m.group(1)]
-                pass
-            elif filename in pyficache.file2file_remap:
-                remapped_file = pyficache.unmap_file(filename)
-                # FIXME: a remapped_file shouldn't be the same as its unmapped version
-                if remapped_file == filename:
-                    remapped_file = None
-                    pass
-                pass
-            elif pyficache.main.remap_re_hash:
-                remapped_file = pyficache.remap_file_pat(
-                    filename, pyficache.main.remap_re_hash
-                )
-            elif m and m.group(1) in sys.modules:
-                remapped_file = m.group(1)
-                pyficache.remap_file(filename, remapped_file)
-            pass
-
-        opts = {
-            "reload_on_change": proc_obj.settings("reload"),
-            "output": proc_obj.settings("highlight"),
-        }
-
-        if "style" in proc_obj.debugger.settings:
-            opts["style"] = proc_obj.settings("style")
-
-        pyficache.update_cache(filename)
-        line = pyficache.getline(filename, lineno, opts)
-        if not line:
-            if (
-                not source_text
-                and filename.startswith("<string: ")
-                and proc_obj.curframe.f_code
-                and have_deparse_and_cache
-            ):
-                # Deparse the code object into a temp file and remap the line from code
-                # into the corresponding line of the tempfile
-                co = proc_obj.curframe.f_code
-                tempdir = proc_obj.settings("tempdir")
-                temp_filename, name_for_code = deparse_and_cache(
-                    co, proc_obj.errmsg, tempdir=tempdir
-                )
-                lineno = 1
-                # _, lineno = pyficache.unmap_file_line(temp_filename, lineno, True)
-                if temp_filename:
-                    filename = temp_filename
-                pass
-
-            else:
-                # FIXME:
-                if source_text:
-                    lines = source_text.split("\n")
-                    temp_name = "string-"
-                else:
-                    # try with good ol linecache and consider fixing pyficache
-                    lines = linecache.getlines(filename)
-                    temp_name = filename
-                if lines:
-                    # FIXME: DRY code with version in cmdproc.py print_location
-                    prefix = osp.basename(temp_name).split(".")[0]
-                    fd = tempfile.NamedTemporaryFile(
-                        suffix=".py",
-                        prefix=prefix,
-                        delete=False,
-                        dir=proc_obj.settings("tempdir"),
-                    )
-                    with fd:
-                        fd.write("".join(lines).encode("utf-8"))
-                        remapped_file = fd.name
-                        pyficache.remap_file(remapped_file, filename)
-                    fd.close()
-                    intf_obj.msg(f"remapped file {filename} to {remapped_file}")
-
-                    pass
-            line = linecache.getline(filename, lineno, proc_obj.curframe.f_globals)
-            if not line:
-                m = re.search("^<frozen (.*)>", filename)
-                if m and m.group(1):
-                    remapped_file = m.group(1)
-                    try_module = sys.modules.get(remapped_file)
-                    if (
-                        try_module
-                        and inspect.ismodule(try_module)
-                        and hasattr(try_module, "__file__")
-                    ):
-                        remapped_file = sys.modules[remapped_file].__file__
-                        pyficache.remap_file(filename, remapped_file)
-                        line = linecache.getline(
-                            remapped_file, lineno, proc_obj.curframe.f_globals
-                        )
-                    else:
-                        remapped_file = m.group(1)
-                        code = proc_obj.curframe.f_code
-                        filename, line = cmdfns.deparse_getline(
-                            code, remapped_file, lineno, opts
-                        )
-                    pass
-            pass
-
-        try:
-            match, reason = Mstack.check_path_with_frame(frame, filename)
-            if not match:
-                if filename not in warned_file_mismatches:
-                    proc_obj.errmsg(reason)
-                    warned_file_mismatches.add(filename)
-        except Exception:
-            pass
-
-        fn_name = frame.f_code.co_name
-        last_i = frame.f_lasti
-        print_source_location_info(
-            intf_obj.msg,
-            filename,
-            lineno,
-            fn_name,
-            remapped_file=remapped_file,
-            f_lasti=last_i,
-        )
-        if line and len(line.strip()) != 0:
-            if proc_obj.event:
-                print_source_line(
-                    intf_obj.msg, lineno, line, proc_obj.event2short[proc_obj.event]
-                )
-            pass
-        if "<string>" != filename:
-            break
-        pass
-
-    if proc_obj.event in ["return", "exception"]:
-        val = proc_obj.event_arg
-        intf_obj.msg(f"R=> {proc_obj._saferepr(val)}")
-        pass
-    elif (
-        proc_obj.event == "call"
-        and proc_obj.curframe.f_locals.get("__name__", "") != "__main__"
-    ):
-        try:
-            proc_obj.commands["info"].run(["info", "locals"])
-        except Exception:
-            pass
-    return True
-
-
 # Default settings for command processor method call
 DEFAULT_PROC_OPTS = {
     # A list of debugger initialization files to read on first command
@@ -409,7 +158,13 @@ class CommandProcessor(Processor):
         get_option = get_option_fn
         super().__init__(core_obj)
 
-        self.continue_running = False  # True if we should leave command loop
+        self.aliases = {}
+
+        # "fast_continue" is used if we should try to see if we can
+        # remove the debugger callback hook altogether. It is used by
+        # the "continue" command, but not stepping (step, next, finish).
+        self.fast_continue = False
+
         self.event2short = dict(EVENT2SHORT)
         self.event2short["signal"] = "?!"
         self.event2short["brkpt"] = "xx"
@@ -424,7 +179,7 @@ class CommandProcessor(Processor):
         # command name before alias or macro resolution
         self.cmd_name = ""
         self.cmd_queue = []  # Queued debugger commands
-        self.completer = lambda text, state: Mcomplete.completer(self, text, state)
+        self.completer = lambda text, state: completer(self, text, state)
         self.current_command = ""  # Current command getting run
         self.debug_nest = 1
         self.display_mgr = Mdisplay.DisplayMgr()
@@ -440,11 +195,6 @@ class CommandProcessor(Processor):
 
         self._populate_cmd_lists()
 
-        # Note: prompt_str's value set below isn't used. It is
-        # computed dynamically. The value is suggestive of what it
-        # looks like.
-        self.prompt_str = "(trepan3k) "
-
         # Stop only if line/file is different from last time
         self.different_line = None
 
@@ -477,6 +227,40 @@ class CommandProcessor(Processor):
         initfile_list = get_option("initfile_list")
         for init_cmdfile in initfile_list:
             self.queue_startfile(init_cmdfile)
+
+        self.set_prompt()
+
+        # Set up prompt-toolkit completion
+        if self.is_using_prompt_toolkit():
+            from trepan.processor.complete_ptk import Trepan3KCompleter
+
+            trepan3k_completer = Trepan3KCompleter(
+                list(self.commands.keys()), self.aliases
+            )
+
+            for cmd, cmd_obj in self.commands.items():
+                if hasattr(cmd_obj, "cmds") and hasattr(cmd_obj.cmds, "cmdlist"):
+                    trepan3k_completer.add_completions(
+                        cmd, sorted(cmd_obj.cmds.cmdlist)
+                    )
+                    for subcmd_name, subcmd_obj in cmd_obj.cmds.subcmds.items():
+                        subcmd_key = f"{cmd} {subcmd_name}"
+                        if hasattr(subcmd_obj, "completion_choices"):
+                            trepan3k_completer.add_completions(
+                                subcmd_key, sorted(subcmd_obj.completion_choices)
+                            )
+                            pass
+                        pass
+                elif hasattr(cmd_obj, "completion_choices"):
+                    trepan3k_completer.add_completions(
+                        cmd, sorted(cmd_obj.completion_choices)
+                    )
+                    pass
+                pass
+
+            for i in self.intf:
+                if i.input.session is not None:
+                    i.input.session.completer = trepan3k_completer
         return
 
     def _saferepr(self, str, maxwidth=None):
@@ -484,7 +268,7 @@ class CommandProcessor(Processor):
             maxwidth = self.debugger.settings["width"]
         return self._repr.repr(str)[:maxwidth]
 
-    def add_preloop_hook(self, hook, position=-1, nodups=True):
+    def add_preloop_hook(self, hook, position=-1, _=True):
         if hook in self.preloop_hooks:
             return False
         self.preloop_hooks.insert(position, hook)
@@ -497,8 +281,10 @@ class CommandProcessor(Processor):
             pyficache.file2file_remap = {}
 
     # To be overridden in derived debuggers
-    def defaultFile(self):
+    def defaultFile(self) -> Optional[str]:
         """Produce a reasonable default."""
+        if self.curframe is None:
+            return None
         filename = self.curframe.f_code.co_filename
         # Consider using is_exec_stmt(). I just don't understand
         # the conditions under which the below test is true.
@@ -513,7 +299,8 @@ class CommandProcessor(Processor):
             pass
         self.prompt_str = f"{'(' * self.debug_nest}{prompt}{')' * self.debug_nest}"
         highlight = self.debugger.settings["highlight"]
-        if highlight and highlight in ("light", "dark"):
+        using_prompt_toolkit = self.is_using_prompt_toolkit()
+        if not using_prompt_toolkit and highlight and highlight in ("light", "dark"):
             self.prompt_str = colorize("underline", self.prompt_str)
         self.prompt_str += " "
 
@@ -568,8 +355,13 @@ class CommandProcessor(Processor):
 
     def forget(self):
         """Remove memory of state variables set in the command processor"""
+
+        # call frame stack.
         self.stack = []
+
+        # Current frame index in call frame stack; 0 is the oldest frame.
         self.curindex = 0
+
         self.curframe = None
         self.thread_name = None
         self.frame_thread_name = None
@@ -580,18 +372,18 @@ class CommandProcessor(Processor):
         try:
             return eval(arg, self.curframe.f_globals, self.curframe.f_locals)
         except Exception:
-            t, v = sys.exc_info()[:2]
+            t, _ = sys.exc_info()[:2]
             if isinstance(t, str):
                 exc_type_name = t
                 pass
             else:
                 exc_type_name = t.__name__
             if show_error:
-                self.errmsg(str(f"{exc_type_name}: {arg}"))
+                self.errmsg(f"{exc_type_name}: {arg}")
             raise
         return None  # Not reached
 
-    def exec_line(self, line):
+    def exec_line(self, line: str):
         if self.curframe:
             local_vars = self.curframe.f_locals
             global_vars = self.curframe.f_globals
@@ -607,7 +399,7 @@ class CommandProcessor(Processor):
             exec(code, global_vars, local_vars)
         except Exception:
             t, v = sys.exc_info()[:2]
-            if type(t) == bytes:
+            if isinstance(t, bytes):
                 exc_type_name = t
             else:
                 exc_type_name = t.__name__
@@ -615,7 +407,9 @@ class CommandProcessor(Processor):
             pass
         return
 
-    def get_an_int(self, arg, msg_on_error, min_value=None, max_value=None):
+    def get_an_int(
+        self, arg, msg_on_error, min_value=None, max_value=None
+    ) -> Optional[int]:
         """Like cmdfns.get_an_int(), but if there's a stack frame use that
         in evaluation."""
         ret_value = self.get_int_noerr(arg)
@@ -656,7 +450,9 @@ class CommandProcessor(Processor):
             return None
         return val
 
-    def get_int(self, arg, min_value=0, default=1, cmdname=None, at_most=None):
+    def get_int(
+        self, arg, min_value=0, default=1, cmdname=None, at_most=None
+    ) -> Optional[int]:
         """If no argument use the default. If arg is a an integer between
         least min_value and at_most, use that. Otherwise report an error.
         If there's a stack frame use that in evaluation."""
@@ -674,7 +470,6 @@ class CommandProcessor(Processor):
                 self.errmsg(f"Expecting a positive integer, got: {str(arg)}")
                 pass
             return None
-            pass
         if default < min_value:
             if cmdname:
                 self.errmsg(
@@ -717,6 +512,9 @@ class CommandProcessor(Processor):
             raise
         return
 
+    def is_using_prompt_toolkit(self) -> bool:
+        return self.intf[-1].input.session is not None
+
     def ok_for_running(self, cmd_obj, name, nargs):
         """We separate some of the common debugger command checks here:
         whether it makes sense to run the command in this execution state,
@@ -759,6 +557,7 @@ class CommandProcessor(Processor):
 
         leave_loop = run_hooks(self, self.preloop_hooks)
         self.continue_running = False
+        self.fast_continue = False
 
         while not leave_loop:
             try:
@@ -781,13 +580,23 @@ class CommandProcessor(Processor):
                     self.last_command = ""
                 else:
                     if self.debugger.intf[-1].output:
-                        self.debugger.intf[-1].output.writeline("Leaving")
+                        self.debugger.intf[-1].msg("Leaving")
                         raise SystemExit
                         pass
                     break
                 pass
             pass
-        return run_hooks(self, self.postcmd_hooks)
+        run_hooks(self, self.postcmd_hooks)
+        if self.fast_continue and len(self.core.bpmgr.bplist) == 0:
+            # Remove tracing on frames and remove trace hook.
+            frame = self.curframe
+            while frame:
+                del frame.f_trace
+                frame = frame.f_back
+            self.debugger.intf[-1].msg("Fast continue...")
+            remove_hook(self.core.trace_dispatch, True)
+
+        return
 
     def process_command(self):
         # process command
@@ -868,6 +677,11 @@ class CommandProcessor(Processor):
 
                 self.cmd_name = args[0]
                 cmd_name = resolve_name(self, self.cmd_name)
+                if cmd_name is not None and cmd_name.find(" ") > 0:
+                    # May have an alias with args
+                    args = cmd_name.split(" ") + args[1:]
+                    cmd_name = args[0]
+
                 self.cmd_argstr = current_command[len(self.cmd_name) :].lstrip()
                 if cmd_name:
                     self.last_command = current_command
@@ -921,6 +735,8 @@ class CommandProcessor(Processor):
             pass
         if self.event in ["exception", "c_exception"]:
             exc_type, exc_value, exc_traceback = self.event_arg
+        elif self.event == "finished":
+            self.frame = exc_traceback = None
         else:
             _, _, exc_traceback = (
                 None,
@@ -968,7 +784,11 @@ class CommandProcessor(Processor):
         expanded_cmdfile = osp.expanduser(cmdfile)
         is_readable = Mfile.readable(expanded_cmdfile)
         if is_readable:
-            self.cmd_queue.append("source " + expanded_cmdfile)
+            script_intf = ScriptInterface(
+                expanded_cmdfile, out=self.debugger.intf[-1].output
+            )
+            self.debugger.intf.append(script_intf)
+            # self.cmd_queue.append("source " + expanded_cmdfile)
         elif is_readable is None:
             self.errmsg(f"source file '{expanded_cmdfile}' doesn't exist")
         else:
@@ -1025,18 +845,18 @@ class CommandProcessor(Processor):
         if hasattr(Mcommand, "__modules__"):
             return self.populate_commands_easy_install(Mcommand)
         else:
-            return self.populate_commands_pip(Mcommand, "trepan")
+            return self.populate_commands_pip(Mcommand)
 
     def populate_commands_pip(self, Mcommand):
         cmd_instances = []
-        eval_cmd_template = "command_mod.%s(self)"
+        eval_cmd_template = "command_module.%s(self)"
         for mod_name in Mcommand.__dict__.keys():
             if mod_name.startswith("__"):
                 continue
             import_name = "trepan.processor.command." + mod_name
             imp = __import__(import_name)
             if imp.__name__ == mod_name:
-                command_mod = imp.processor.command
+                command_module = imp.processor.command
             else:
                 if mod_name in (
                     "info_sub",
@@ -1045,7 +865,7 @@ class CommandProcessor(Processor):
                 ):
                     pass
                 try:
-                    command_mod = getattr(__import__(import_name), mod_name)
+                    command_module = getattr(__import__(import_name), mod_name)
                 except Exception:
                     # Don't need to warn about optional modules
                     if mod_name not in self.optional_modules:
@@ -1056,24 +876,19 @@ class CommandProcessor(Processor):
 
             classnames = [
                 tup[0]
-                for tup in inspect.getmembers(command_mod, inspect.isclass)
+                for tup in inspect.getmembers(command_module, inspect.isclass)
                 if ("DebuggerCommand" != tup[0] and tup[0].endswith("Command"))
             ]
             for classname in classnames:
                 eval_cmd = eval_cmd_template % classname
-                if False:
+                try:
                     instance = eval(eval_cmd)
                     cmd_instances.append(instance)
-                else:
-                    try:
-                        instance = eval(eval_cmd)
-                        cmd_instances.append(instance)
-                    except Exception:
-                        print(
-                            "Error loading %s from %s: %s"
-                            % (classname, mod_name, sys.exc_info()[0])
-                        )
-                        pass
+                except Exception:
+                    print(
+                        "Error loading %s from %s: %s"
+                        % (classname, mod_name, sys.exc_info()[0])
+                    )
                     pass
                 pass
             pass
@@ -1094,9 +909,10 @@ class CommandProcessor(Processor):
                 "show_sub",
             ):
                 pass
+
             import_name = f"{Mcommand.__name__}.{mod_name}"
             try:
-                command_mod = importlib.import_module(import_name)
+                command_module = importlib.import_module(import_name)
             except Exception:
                 if mod_name not in self.optional_modules:
                     print(f"Error importing {mod_name}: {sys.exc_info()[0]}")
@@ -1105,23 +921,15 @@ class CommandProcessor(Processor):
 
             classnames = [
                 tup[0]
-                for tup in inspect.getmembers(command_mod, inspect.isclass)
+                for tup in inspect.getmembers(command_module, inspect.isclass)
                 if ("DebuggerCommand" != tup[0] and tup[0].endswith("Command"))
             ]
             for classname in classnames:
-                if False:
-                    instance = getattr(command_mod, classname)(self)
+                try:
+                    instance = getattr(command_module, classname)(self)
                     cmd_instances.append(instance)
-                else:
-                    try:
-                        instance = getattr(command_mod, classname)(self)
-                        cmd_instances.append(instance)
-                    except Exception:
-                        print(
-                            "Error loading %s from %s: %s"
-                            % (classname, mod_name, sys.exc_info()[0])
-                        )
-                        pass
+                except Exception:
+                    print(f"Error loading {classname} from mod_name, sys.exc_info()[0]")
                     pass
                 pass
             pass
@@ -1131,7 +939,6 @@ class CommandProcessor(Processor):
         """Populate self.lists and hashes:
         self.commands, and self.aliases, self.category"""
         self.commands = {}
-        self.aliases = {}
         self.category = {}
         #         self.short_help = {}
         for cmd_instance in self.cmd_instances:
@@ -1165,9 +972,9 @@ class CommandProcessor(Processor):
 
 # Demo it
 if __name__ == "__main__":
-    from trepan.processor.command import mock as Mmock
+    from trepan.processor.command.mock import MockDebugger
 
-    d = Mmock.MockDebugger()
+    d = MockDebugger()
     cmdproc = CommandProcessor(d.core)
     print("commands:")
     commands = list(cmdproc.commands.keys())
